@@ -1,9 +1,11 @@
 """Main tldextract unit tests."""
 
+from __future__ import annotations
+
 import logging
 import os
 import tempfile
-from typing import Sequence, Tuple
+from collections.abc import Sequence
 
 import pytest
 import responses
@@ -11,6 +13,7 @@ import responses
 import tldextract
 import tldextract.suffix_list
 from tldextract.cache import DiskCache
+from tldextract.remote import inet_pton, lenient_netloc, looks_like_ip
 from tldextract.suffix_list import SuffixListNotFound
 from tldextract.tldextract import ExtractResult
 
@@ -27,8 +30,9 @@ extract_using_fallback_to_snapshot_no_cache = tldextract.TLDExtract(
 
 def assert_extract(
     url: str,
-    expected_domain_data: Tuple[str, str, str, str],
+    expected_domain_data: tuple[str, str, str, str],
     expected_ip_data: str = "",
+    expected_ipv6_data: str = "",
     funs: Sequence[tldextract.TLDExtract] = (
         extract,
         extract_no_cache,
@@ -55,6 +59,7 @@ def assert_extract(
         assert expected_domain == ext.domain
         assert expected_tld == ext.suffix
         assert expected_ip_data == ext.ipv4
+        assert expected_ipv6_data == ext.ipv6
 
 
 def test_american():
@@ -130,8 +135,45 @@ def test_ip():
     )
 
 
-def test_looks_like_ip():
+def test_lenient_netloc():
+    assert lenient_netloc("https://example.com.ca") == "example.com.ca"
+    assert lenient_netloc("https://[example.com.ca]") == "[example.com.ca]"
+    assert lenient_netloc("https://[example.com.ca]:5000") == "[example.com.ca]"
+    assert (
+        lenient_netloc("https://[aBcD:ef01:2345:6789:aBcD:ef01::]:5000")
+        == "[aBcD:ef01:2345:6789:aBcD:ef01::]"
+    )
+    assert (
+        lenient_netloc("https://[aBcD:ef01:2345:6789:aBcD:ef01:127.0.0.1]:5000")
+        == "[aBcD:ef01:2345:6789:aBcD:ef01:127.0.0.1]"
+    )
+    assert (
+        lenient_netloc(
+            "https://[aBcD:ef01:2345:6789:aBcD:ef01:127\uff0e0\u30020\uff611]:5000"
+        )
+        == "[aBcD:ef01:2345:6789:aBcD:ef01:127\uff0e0\u30020\uff611]"
+    )
+
+
+@pytest.mark.skipif(not inet_pton, reason="inet_pton unavailable")
+def test_looks_like_ip_with_inet_pton():
+    assert looks_like_ip("1.1.1.1", inet_pton) is True
+    assert looks_like_ip("a.1.1.1", inet_pton) is False
+    assert looks_like_ip("1.1.1.1\n", inet_pton) is False
+    assert looks_like_ip("256.256.256.256", inet_pton) is False
+
+
+def test_looks_like_ip_without_inet_pton():
+    assert looks_like_ip("1.1.1.1", None) is True
+    assert looks_like_ip("a.1.1.1", None) is False
+    assert looks_like_ip("1.1.1.1\n", None) is False
+    assert looks_like_ip("256.256.256.256", None) is False
+
+
+def test_similar_to_ip():
     assert_extract("1\xe9", ("", "", "1\xe9", ""))
+    assert_extract("1.1.1.1\ncom", ("", "1.1.1", "1\ncom", ""))
+    assert_extract("1.1.1.1\rcom", ("", "1.1.1", "1\rcom", ""))
 
 
 def test_punycode():
@@ -158,7 +200,7 @@ def test_punycode():
             "com",
         ),
     )
-    # This subdomain generates UnicodeError 'incomplete punicode string'
+    # This subdomain generates UnicodeError 'incomplete punycode string'
     assert_extract(
         "xn--tub-1m9d15sfkkhsifsbqygyujjrw60.google.com",
         (
@@ -185,6 +227,10 @@ def test_invalid_puny_with_puny():
     )
 
 
+def test_invalid_puny_with_nonpuny():
+    assert_extract("xn--ß‌꫶ᢥ.com", ("xn--ß‌꫶ᢥ.com", "", "xn--ß‌꫶ᢥ", "com"))
+
+
 def test_puny_with_non_puny():
     assert_extract(
         "http://xn--zckzap6140b352by.blog.so-net.教育.hk",
@@ -248,6 +294,21 @@ def test_username():
         "ftp://johndoe:5cr1p7k1dd13@1337.warez.com:2501",
         ("1337.warez.com", "1337", "warez", "com"),
     )
+    assert_extract(
+        "https://apple:pass@127.0.0.1:50/a",
+        ("", "", "127.0.0.1", ""),
+        expected_ip_data="127.0.0.1",
+    )
+    assert_extract(
+        "https://apple:pass@[::]:50/a",
+        ("", "", "[::]", ""),
+        expected_ipv6_data="::",
+    )
+    assert_extract(
+        "https://apple:pass@[aBcD:ef01:2345:6789:aBcD:ef01:127.0.0.1]:50/a",
+        ("", "", "[aBcD:ef01:2345:6789:aBcD:ef01:127.0.0.1]", ""),
+        expected_ipv6_data="aBcD:ef01:2345:6789:aBcD:ef01:127.0.0.1",
+    )
 
 
 def test_query_fragment():
@@ -326,6 +387,11 @@ def test_ipv4():
         ("", "", "127.0.0.1", ""),
         expected_ip_data="127.0.0.1",
     )
+    assert_extract(
+        "http://127\u30020\uff0e0\uff611/foo/bar",
+        ("", "", "127.0.0.1", ""),
+        expected_ip_data="127.0.0.1",
+    )
 
 
 def test_ipv4_bad():
@@ -337,6 +403,12 @@ def test_ipv4_bad():
 
 
 def test_ipv4_lookalike():
+    assert_extract(
+        "http://127.0.0/foo/bar", ("", "127.0", "0", ""), expected_ip_data=""
+    )
+    assert_extract(
+        "http://127.0.0.0x1/foo/bar", ("", "127.0.0", "0x1", ""), expected_ip_data=""
+    )
     assert_extract(
         "http://127.0.0.1.9/foo/bar", ("", "127.0.0.1", "9", ""), expected_ip_data=""
     )
